AWSUploadProgressEvent class

A single event emitted by AwsUploader.progressStream

Constructors

AWSUploadProgressEvent({required String uploadId, required AWSUploadStatus status, int progress = 0, String? url, String? error})
const
AWSUploadProgressEvent.fromMap(Map<String, dynamic> map)
factory

Properties

error String?
Error message. Set only on AWSUploadStatus.failed.
final
hashCode int
The hash code for this object.
no setterinherited
progress int
Upload completion percentage (0–100). Non-zero only during AWSUploadStatus.progress and set to 100 when AWSUploadStatus.completed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status AWSUploadStatus
final
uploadId String
final
url String?
S3 URL of the uploaded file. Set only on AWSUploadStatus.completed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited