AWSUploadResult class

Result returned from an AWS S3 file upload attempt

Constructors

AWSUploadResult.failure({required String uploadId, required String errorMessage})
factory
AWSUploadResult.fromMap(Map<String, dynamic> map)
factory

Properties

bucket String
S3 bucket name; empty string on failure
final
errorMessage String?
Error message when success is false, null otherwise
final
fileName String
File name used in S3; empty string on failure
final
filePath String
Local file path that was uploaded; empty string on failure
final
hashCode int
The hash code for this object.
no setterinherited
key String
Full S3 object key (uploadFolder/fileName); empty string on failure
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
Whether the upload succeeded
final
uploadId String
The upload ID that was passed when starting the upload
final
url String
Public S3 URL of the uploaded file; empty string on failure
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited